----------------------------
-- Localized Addon Namespace
----------------------------
local private = select(2, ...)
local addon = LibStub("AceAddon-3.0"):GetAddon(private.addonName)

---- Trade Skill Show
-- Fired by the client when a player opens any tradeskill
-- window. This includes the guild tradeskills and any 
-- other players tradeskill linked in chat.
function addon:TRADE_SKILL_SHOW()
  -- exit early if this is a trade skill link
  if IsTradeSkillLinked() then
    return
  end
  
  -- Register for the close event
  addon:RegisterEvent("TRADE_SKILL_CLOSE")
  
  local tradeskillName, curLevel, maxLevel = GetTradeSkillLine()
  table.insert(addon.db.char[tradeskillName], {level = curLevel, optimal = {}, medium = {}, easy = {}})
  
  -- Parse the trade skill information and update the database
  for i = 1, GetNumTradeSkills() do
    local name, type, _, _, _, ups = GetTradeSkillInfo(i)
    
    if name and type ~= "header" then
      if type == "optimal" then
        table.insert(addon.db.char[tradeskillName].optimal[name], {points = ups})
      elseif type == "medium" then
        table.insert(addon.db.char[tradeskillName].optimal[name], {points = ups})
      elseif type == "easy" then
        table.insert(addon.db.char[tradeskillName].optimal[name], {points = ups})
      end
      
      addon:Print("Found " .. name .. " which is " .. type .. " to make and provides " .. ups .. " skill point(s).")
    end
  end
end

---- Trade Skill Close
-- Fired by the client when a player closes any tradeskill
-- window. This includes the guild tradeskills and any 
-- other players tradeskill linked in chat.
function addon:TRADE_SKILL_CLOSE()
  -- Remove registration for the close and update events
  addon:UnregisterEvent("TRADE_SKILL_CLOSE")
end