----------------------------
-- Localized Addon Namespace
----------------------------
local private = select(2, ...)
local addon = LibStub("AceAddon-3.0"):GetAddon(private.addonName)

----------------------------
-- Localized Library Namespace
----------------------------
local gui = LibStub("AceGUI-3.0")

local function drawTab(container, event, group)
  if not container or container == nil then
    -- print error message
  end
  
  -- release the old tab (if there was one) back into AceGUI's
  -- widget pool for reuse
  container:ReleaseChildren()
  
  -- create a simple group that is 75% of the frames height
  top = gui:Create("SimpleGroup")
  top:SetFullWidth(true)
  -- top:SetHeight()
  top:SetLayout("Fill")
  container:AddChild(top)
  
  -- create a scrolling frame
  scroll = gui:Create("ScrollFrame")
  scroll:SetLayout("Flow")
  top:AddChild(scroll)
  
  -- add a header labeled optimal
  optimalLabel = gui:Create("InteractiveLabel")
  optimalLabel:SetText("Optimal")
  optimalLabel:SetFullWidth(true)
  scroll:AddChild(optimalLabel)
  -- add each optimal skill
    
  -- add a header labeled medium
  mediumLabel = gui:Create("InteractiveLabel")
  mediumLabel:SetText("Medium")
  mediumLabel:SetFullWidth(true)
  scroll:AddChild(mediumLabel)
      -- add each medium skill
    
  -- add a header labeled easy to the ui
  easyLabel = gui:Create("InteractiveLabel")
  easyLabel:SetText("Easy")
  mediumLabel:SetFullWidth(true)
  scroll:AddChild(easyLabel)
  -- add each easy skill
    
  -- create a simple group that is the remaining 25% of the frames height
  bot = gui:Create("SimpleGroup")
  bot:SetFullWidth(true)
  -- bot:SetHeight()
  bot:SetLayout("Flow")
  container:AddChild(bot)
end

function addon:Show()
  local frame = gui:Create("Frame")
  frame:SetTitle(private.addonName)
  frame:SetCallback("OnClose", function(widget) gui:Release(widget) end)
  frame:SetLayout("Fill")
  
  -- Create the tab group
  local tabGroup = gui:Create("TabGroup")
  tabGroup:SetLayout("Flow")
    
  -- Create a tab for each known profession
  local tabs = {}
  for k,v in pairs(addon.db.char) do
    if k and type(v) == "table" then
      table.insert(tabs, {text=k, value=k})
    end
  end
  tabGroup:SetTabs(tabs)
  tabGroup:SetCallback("OnGroupSelected", drawTab)
  
  -- if there is a tradeskill open then start on that tab, 
  -- otherwise start on the first tab
  local skillName = GetTradeSkillLine()
  if skillName and skillName ~= nil then
    tabGroup:SelectTab(skillName)
  else
    tabGroup:SelectTab(tabs[1].value)
  end
  
  frame:AddChild(tabGroup)
end
